@@ -404,6 +404,7 @@ MS2_PUBLIC bool_t ms_media_stream_io_is_consistent(const MSMediaStreamIO *io);
 
 typedef void (*AudioStreamIsSpeakingCallback)(void *user_pointer, uint32_t speaker_ssrc, bool_t is_speaking);
 typedef void (*AudioStreamIsMutedCallback)(void *user_pointer, uint32_t speaker_ssrc, bool_t is_muted);
+typedef void (*AudioStreamActiveSpeakerCallback)(void *user_pointer, uint32_t speaker_ssrc);
 typedef void (*MSAudioRouteChangedCallback)(void* audioStream, bool_t needReloadSoundDevices, char* newInputPort, char* newOutputPort);
 struct _AudioStream
 {
@@ -472,11 +473,13 @@ struct _AudioStream
 	struct _AudioStreamVolumes *participants_volumes;
 	int mixer_to_client_extension_id;
 	int client_to_mixer_extension_id;
-	uint32_t speaking_ssrc;
 	AudioStreamIsSpeakingCallback is_speaking_cb;
+	void *is_speaking_user_pointer;
 	AudioStreamIsMutedCallback is_muted_cb;
-	void *user_pointer;
-	bool_t is_speaking;
+	void *is_muted_user_pointer;
+	AudioStreamActiveSpeakerCallback active_speaker_cb;
+	void *active_speaker_user_pointer;
+	uint32_t active_speaker_ssrc;
 	MSAudioRouteChangedCallback audio_route_changed_cb;
 	void * audio_route_changed_cb_user_data;
 };
@@ -899,6 +902,8 @@ MS2_PUBLIC void audio_stream_set_client_to_mixer_extension_id(AudioStream *strea
 
 MS2_PUBLIC void audio_stream_set_is_speaking_callback(AudioStream *s, AudioStreamIsSpeakingCallback cb, void *user_pointer);
 MS2_PUBLIC void audio_stream_set_is_muted_callback(AudioStream *s, AudioStreamIsMutedCallback cb, void *user_pointer);
+MS2_PUBLIC void
+audio_stream_set_active_speaker_callback(AudioStream *s, AudioStreamActiveSpeakerCallback cb, void *user_pointer);
 
 /**
  * Retrieve the volume of the given participant.
@@ -958,8 +963,10 @@ MS2_PUBLIC uint32_t audio_stream_volumes_get_best(AudioStreamVolumes *volumes);
  * @{
 **/
 
+
 typedef void (*VideoStreamRenderCallback)(void *user_pointer, const MSPicture *local_view, const MSPicture *remote_view);
 typedef void (*VideoStreamEventCallback)(void *user_pointer, const MSFilter *f, const unsigned int event_id, const void *args);
+typedef void (*VideoStreamDisplayCallback)(void *user_pointer, const unsigned int event_id, const void *args);/* if coming from OpenGL and event_id==MS_VIDEO_DISPLAY_ERROR_OCCURRED, args is an int from eglGetError() : https://registry.khronos.org/EGL/sdk/docs/man/html/eglGetError.xhtml */
 typedef void (*VideoStreamCameraNotWorkingCallback)(void *user_pointer, const MSWebCam *old_webcam);
 typedef void (*VideoStreamEncoderControlCb)(struct _VideoStream *, unsigned int method_id, void *arg, void *user_data);
 typedef void (*VideoStreamCsrcChangedCb)(void *user_pointer, uint32_t new_csrc);
@@ -1010,6 +1017,8 @@ struct _VideoStream
 	void *render_pointer;
 	VideoStreamEventCallback eventcb;
 	void *event_pointer;
+	VideoStreamDisplayCallback displaycb;
+	void *display_pointer;
 	char *display_name;
 	void *window_id;
 	void *preview_window_id;
@@ -1045,6 +1054,7 @@ struct _VideoStream
 	bool_t staticimage_webcam_fps_optimization; /* if TRUE, the StaticImage webcam will ignore the fps target in order to save CPU time. Default is TRUE */
 	bool_t is_forwarding;
 	bool_t wait_for_frame_decoded;
+	bool_t fallback_to_dummy_codec; /**< if TRUE, enable fallback to dummy codec when the requested one is not supported - used to build a videostream in the conference server */
 	VideoStreamCsrcChangedCb csrc_changed_cb;
 	void *csrc_changed_cb_user_data;
 	uint32_t new_csrc;
@@ -1078,6 +1088,8 @@ static MS2_INLINE void video_stream_enable_adaptive_jittcomp(VideoStream *stream
 }
 MS2_PUBLIC void video_stream_set_render_callback(VideoStream *s, VideoStreamRenderCallback cb, void *user_pointer);
 MS2_PUBLIC void video_stream_set_event_callback(VideoStream *s, VideoStreamEventCallback cb, void *user_pointer);
+MS2_PUBLIC void video_stream_set_display_callback(VideoStream *s, VideoStreamDisplayCallback cb, void *user_pointer);
+
 MS2_PUBLIC void video_stream_set_camera_not_working_callback(VideoStream *s, VideoStreamCameraNotWorkingCallback cb, void *user_pointer);
 MS2_PUBLIC void video_stream_set_display_filter_name(VideoStream *s, const char *fname);
 MS2_PUBLIC void video_stream_set_label(VideoStream *s, const char *label);
@@ -1284,6 +1296,7 @@ MS2_PUBLIC void video_stream_set_device_rotation(VideoStream *stream, int orient
 MS2_PUBLIC void video_stream_show_video(VideoStream *stream, bool_t show);
 MS2_PUBLIC void video_stream_set_freeze_on_error(VideoStream *stream, bool_t yesno);
 MS2_PUBLIC void video_stream_set_display_mode(VideoStream *stream, MSVideoDisplayMode mode);
+MS2_PUBLIC void video_stream_set_fallback_to_dummy_codec(VideoStream *stream, bool_t yesno);
 
 /**
  * @brief Gets the camera sensor rotation.
@@ -1441,8 +1454,10 @@ MS2_PUBLIC void video_stream_set_csrc_changed_callback(VideoStream *stream, Vide
 
 typedef VideoStream VideoPreview;
 
+
 MS2_PUBLIC VideoPreview * video_preview_new(MSFactory *factory);
 #define video_preview_set_event_callback(p,c,u) video_stream_set_event_callback(p,c,u)
+#define video_preview_set_display_callback(p, c, u) video_stream_set_display_callback(p, c, u)
 #define video_preview_set_size(p,s) video_stream_set_sent_video_size(p,s)
 #define video_preview_set_display_filter_name(p,dt) video_stream_set_display_filter_name(p,dt)
 #define video_preview_create_native_window_id(p) video_stream_create_native_preview_window_id(p)
