@@ -1,19 +1,20 @@
 /*
- * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ * Copyright (c) 2010-2022 Belledonne Communications SARL.
  *
- * This file is part of mediastreamer2.
+ * This file is part of mediastreamer2 
+ * (see https://gitlab.linphone.org/BC/public/mediastreamer2).
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU Affero General Public License as
+ * published by the Free Software Foundation, either version 3 of the
+ * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Affero General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Affero General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
@@ -81,8 +82,15 @@
 
 #define MS_VOLUME_DB_LOWEST		(-120)	/*arbitrary value returned when linear volume is 0*/
 
+#define MS_VOLUME_DB_MUTED (-130) /*-130 because in dBov -127 is digital silence*/
+
+#define MS_VOLUME_DB_MIN_THRESHOLD (-30) /*value at which we consider the participant is speaking*/
+
 extern MSFilterDesc ms_volume_desc;
 
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 // Utils functions to convert volumes
 MS2_PUBLIC float ms_volume_linear_to_dbm0(float linear);
@@ -94,4 +102,8 @@ MS2_PUBLIC int ms_volume_dbm0_to_dbov(float dbm0);
 MS2_PUBLIC float ms_volume_dbov_to_linear(int dbov);
 MS2_PUBLIC float ms_volume_dbov_to_dbm0(int dbov);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
